@@ -5,7 +5,7 @@
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
  *
- *       http://www.apache.org/licenses/LICENSE-2.0
+ *     http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -21,8 +21,10 @@ import java.util.Collections;
 import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
+import java.util.Optional;
 import java.util.stream.Stream;
 
+import com.google.gwt.event.dom.client.ClickEvent;
 import com.google.gwt.event.dom.client.ClickHandler;
 import com.google.gwt.user.client.Command;
 import com.google.gwt.user.client.ui.HorizontalPanel;
@@ -43,30 +45,40 @@ import org.drools.workbench.screens.guided.dtable.client.resources.GuidedDecisio
 import org.drools.workbench.screens.guided.dtable.client.resources.i18n.GuidedDecisionTableConstants;
 import org.drools.workbench.screens.guided.dtable.client.widget.table.GuidedDecisionTableModellerView;
 import org.drools.workbench.screens.guided.dtable.client.widget.table.GuidedDecisionTableView;
+import org.drools.workbench.screens.guided.dtable.client.widget.table.model.synchronizers.ModelSynchronizer.VetoDeletePatternInUseException;
+import org.drools.workbench.screens.guided.dtable.client.widget.table.model.synchronizers.ModelSynchronizer.VetoException;
 import org.jboss.errai.ioc.client.api.ManagedInstance;
 import org.junit.Before;
 import org.junit.Test;
 import org.junit.runner.RunWith;
 import org.mockito.ArgumentCaptor;
+import org.mockito.Captor;
 import org.mockito.Mock;
+import org.mockito.Mockito;
 
+import static org.junit.Assert.fail;
 import static org.mockito.Matchers.any;
 import static org.mockito.Matchers.anyString;
 import static org.mockito.Matchers.eq;
 import static org.mockito.Mockito.doNothing;
 import static org.mockito.Mockito.doReturn;
+import static org.mockito.Mockito.doThrow;
 import static org.mockito.Mockito.mock;
 import static org.mockito.Mockito.never;
 import static org.mockito.Mockito.reset;
 import static org.mockito.Mockito.spy;
 import static org.mockito.Mockito.times;
 import static org.mockito.Mockito.verify;
+import static org.mockito.Mockito.when;
 
 @RunWith(GwtMockitoTestRunner.class)
 public class ColumnManagementViewTest {
 
     @Mock
-    private GuidedDecisionTableModellerView.Presenter presenter;
+    private GuidedDecisionTableModellerView modellerView;
+
+    @Mock
+    private GuidedDecisionTableModellerView.Presenter modellerPresenter;
 
     @Mock
     private GuidedDecisionTableView.Presenter decisionTablePresenter;
@@ -80,6 +92,12 @@ public class ColumnManagementViewTest {
     @Mock
     private ManagedInstance<DeleteColumnManagementAnchorWidget> deleteColumnManagementAnchorWidgets;
 
+    @Captor
+    private ArgumentCaptor<ClickHandler> clickHandlerCaptor;
+
+    @Captor
+    private ArgumentCaptor<Command> deleteCommandCaptor;
+
     private ColumnManagementView view;
 
     @Before
@@ -87,9 +105,12 @@ public class ColumnManagementViewTest {
         doReturn(deleteWidget).when(deleteColumnManagementAnchorWidgets).get();
 
         view = spy(new ColumnManagementView(deleteColumnManagementAnchorWidgets));
-        view.init(presenter);
+        view.init(modellerPresenter);
 
+        doReturn(modellerView).when(modellerPresenter).getView();
         doReturn(horizontalPanel).when(view).newHorizontalPanel();
+
+        when(modellerPresenter.getActiveDecisionTable()).thenReturn(Optional.of(decisionTablePresenter));
     }
 
     private ColumnLabelWidget mockColumnLabelWidget() {
@@ -126,7 +147,7 @@ public class ColumnManagementViewTest {
         final ColumnLabelWidget columnLabel = mockColumnLabelWidget();
 
         doReturn(columnLabel).when(view).newColumnLabelWidget(anyString());
-        doReturn(true).when(presenter).isActiveDecisionTableEditable();
+        doReturn(true).when(modellerPresenter).isActiveDecisionTableEditable();
 
         view.renderColumns(columnGroups);
 
@@ -135,13 +156,25 @@ public class ColumnManagementViewTest {
         verify(horizontalPanel,
                times(3)).add(columnLabel);
         verify(view,
-               times(3)).editAnchor(any(ClickHandler.class));
+               times(3)).editAnchor(clickHandlerCaptor.capture());
         verify(view).deleteAnchor(eq("one"),
                                   any(Command.class));
         verify(view).deleteAnchor(eq("two"),
                                   any(Command.class));
         verify(view).deleteAnchor(eq("three"),
                                   any(Command.class));
+
+        clickHandlerCaptor.getAllValues().get(0).onClick(mock(ClickEvent.class));
+        verify(decisionTablePresenter).editCondition(eq(pattern),
+                                                     eq(pattern.getChildColumns().get(0)));
+
+        clickHandlerCaptor.getAllValues().get(1).onClick(mock(ClickEvent.class));
+        verify(decisionTablePresenter).editCondition(eq(pattern),
+                                                     eq(pattern.getChildColumns().get(1)));
+
+        clickHandlerCaptor.getAllValues().get(2).onClick(mock(ClickEvent.class));
+        verify(decisionTablePresenter).editCondition(eq(pattern),
+                                                     eq(pattern.getChildColumns().get(2)));
     }
 
     @Test
@@ -195,7 +228,7 @@ public class ColumnManagementViewTest {
         final ColumnLabelWidget columnLabel = mockColumnLabelWidget();
 
         doReturn(columnLabel).when(view).newColumnLabelWidget(anyString());
-        doReturn(true).when(presenter).isActiveDecisionTableEditable();
+        doReturn(true).when(modellerPresenter).isActiveDecisionTableEditable();
         doReturn("brl one").when(conditionColumnOne).getHeader();
         doReturn("brl two").when(conditionColumnTwo).getHeader();
 
@@ -208,11 +241,17 @@ public class ColumnManagementViewTest {
         verify(horizontalPanel,
                times(2)).add(columnLabel);
         verify(view,
-               times(2)).editAnchor(any(ClickHandler.class));
+               times(2)).editAnchor(clickHandlerCaptor.capture());
         verify(view).deleteAnchor(eq("brl one"),
                                   any(Command.class));
         verify(view).deleteAnchor(eq("brl two"),
                                   any(Command.class));
+
+        clickHandlerCaptor.getAllValues().get(0).onClick(mock(ClickEvent.class));
+        verify(decisionTablePresenter).editCondition(eq(conditionColumnOne));
+
+        clickHandlerCaptor.getAllValues().get(1).onClick(mock(ClickEvent.class));
+        verify(decisionTablePresenter).editCondition(eq(conditionColumnTwo));
     }
 
     @Test
@@ -264,7 +303,7 @@ public class ColumnManagementViewTest {
         final ColumnLabelWidget columnLabel = mockColumnLabelWidget();
 
         doReturn(columnLabel).when(view).newColumnLabelWidget(anyString());
-        doReturn(true).when(presenter).isActiveDecisionTableEditable();
+        doReturn(true).when(modellerPresenter).isActiveDecisionTableEditable();
         doReturn("one").when(brlActionColumn).getHeader();
         doReturn("two").when(actionInsertFactColumn).getHeader();
         doReturn("three").when(retractFactColumn).getHeader();
@@ -279,13 +318,31 @@ public class ColumnManagementViewTest {
         verify(horizontalPanel,
                times(3)).add(columnLabel);
         verify(view,
-               times(3)).editAnchor(any(ClickHandler.class));
+               times(3)).editAnchor(clickHandlerCaptor.capture());
         verify(view).deleteAnchor(eq("one"),
-                                  any(Command.class));
+                                  deleteCommandCaptor.capture());
         verify(view).deleteAnchor(eq("two"),
-                                  any(Command.class));
+                                  deleteCommandCaptor.capture());
         verify(view).deleteAnchor(eq("three"),
-                                  any(Command.class));
+                                  deleteCommandCaptor.capture());
+
+        clickHandlerCaptor.getAllValues().get(0).onClick(mock(ClickEvent.class));
+        verify(decisionTablePresenter).editAction(eq(brlActionColumn));
+
+        clickHandlerCaptor.getAllValues().get(1).onClick(mock(ClickEvent.class));
+        verify(decisionTablePresenter).editAction(eq(actionInsertFactColumn));
+
+        clickHandlerCaptor.getAllValues().get(2).onClick(mock(ClickEvent.class));
+        verify(decisionTablePresenter).editAction(eq(retractFactColumn));
+
+        deleteCommandCaptor.getAllValues().get(0).execute();
+        verify(decisionTablePresenter).deleteColumn(brlActionColumn);
+
+        deleteCommandCaptor.getAllValues().get(1).execute();
+        verify(decisionTablePresenter).deleteColumn(actionInsertFactColumn);
+
+        deleteCommandCaptor.getAllValues().get(2).execute();
+        verify(decisionTablePresenter).deleteColumn(retractFactColumn);
     }
 
     @Test
@@ -302,7 +359,7 @@ public class ColumnManagementViewTest {
 
         final ColumnLabelWidget columnLabel = mockColumnLabelWidget();
 
-        doReturn(columnLabel).when(view).newColumnLabelWidget(anyString());
+        doReturn(columnLabel).when(view).newColumnLabelWidget(any());
 
         view.renderColumns(columnGroups);
 
@@ -364,13 +421,12 @@ public class ColumnManagementViewTest {
     public void testRemoveCondition() throws Exception {
         Stream.of(ConditionCol52.class,
                   BRLConditionColumn.class)
-                .map(classToMock -> mock(classToMock))
+                .map(Mockito::mock)
                 .forEach(column -> {
                     final String columnHeader = "column header";
                     final ArgumentCaptor<Command> commandCaptor = ArgumentCaptor.forClass(Command.class);
 
-                    doReturn(true).when(decisionTablePresenter).canConditionBeDeleted(column);
-                    doReturn(decisionTablePresenter).when(presenter).getActiveDecisionTable();
+                    doReturn(Optional.of(decisionTablePresenter)).when(modellerPresenter).getActiveDecisionTable();
                     doReturn(columnHeader).when(column).getHeader();
 
                     view.removeCondition(column);
@@ -380,7 +436,11 @@ public class ColumnManagementViewTest {
 
                     commandCaptor.getValue().execute();
 
-                    verify(decisionTablePresenter).deleteColumn(column);
+                    try {
+                        verify(decisionTablePresenter).deleteColumn(column);
+                    } catch (VetoException veto) {
+                        fail("Deletion should have succeeded.");
+                    }
                     reset(view);
                 });
     }
@@ -389,25 +449,28 @@ public class ColumnManagementViewTest {
     public void testRemoveConditionCanNotBeDeleted() throws Exception {
         Stream.of(ConditionCol52.class,
                   BRLConditionColumn.class)
-                .map(classToMock -> mock(classToMock))
+                .map(Mockito::mock)
                 .forEach(column -> {
                     final String columnHeader = "column header";
                     final ArgumentCaptor<Command> commandCaptor = ArgumentCaptor.forClass(Command.class);
 
-                    doReturn(false).when(decisionTablePresenter).canConditionBeDeleted(column);
-                    doReturn(decisionTablePresenter).when(presenter).getActiveDecisionTable();
+                    doReturn(Optional.of(decisionTablePresenter)).when(modellerPresenter).getActiveDecisionTable();
                     doReturn(columnHeader).when(column).getHeader();
-                    doNothing().when(view).showUnableToDeleteColumnMessage(column);
+                    doNothing().when(modellerView).showUnableToDeleteColumnMessage(column);
 
-                    view.removeCondition(column);
+                    try {
+                        doThrow(VetoDeletePatternInUseException.class).when(decisionTablePresenter).deleteColumn(eq(column));
 
-                    verify(view).deleteAnchor(eq("column header"),
-                                              commandCaptor.capture());
+                        view.removeCondition(column);
 
-                    commandCaptor.getValue().execute();
+                        verify(view).deleteAnchor(eq("column header"),
+                                                  commandCaptor.capture());
 
-                    verify(decisionTablePresenter,
-                           never()).deleteColumn(column);
+                        commandCaptor.getValue().execute();
+
+                        verify(modellerView).showUnableToDeleteColumnMessage(eq(column));
+                    } catch (VetoException veto) {
+                    }
                     reset(view);
                 });
     }
