@@ -5,7 +5,7 @@
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
  *
- *       http://www.apache.org/licenses/LICENSE-2.0
+ *     http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -23,18 +23,23 @@ import java.util.List;
 import org.drools.workbench.models.guided.dtable.shared.model.BaseColumnFieldDiff;
 import org.drools.workbench.models.guided.dtable.shared.model.MetadataCol52;
 import org.drools.workbench.screens.guided.dtable.client.widget.table.columns.StringUiColumn;
-import org.drools.workbench.screens.guided.dtable.client.widget.table.model.synchronizers.ModelSynchronizer;
+import org.drools.workbench.screens.guided.dtable.client.widget.table.model.synchronizers.ModelSynchronizer.VetoException;
 import org.junit.Test;
 import org.uberfire.ext.wires.core.grids.client.model.GridColumn;
 import org.uberfire.ext.wires.core.grids.client.model.impl.BaseGridCellValue;
 
-import static org.junit.Assert.*;
-import static org.mockito.Mockito.*;
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertFalse;
+import static org.junit.Assert.assertTrue;
+import static org.mockito.Mockito.mock;
+import static org.mockito.Mockito.spy;
+import static org.mockito.Mockito.verify;
+import static org.mockito.Mockito.when;
 
 public class MetaDataColumnSynchronizerTest extends BaseSynchronizerTest {
 
     @Test
-    public void testAppend() throws ModelSynchronizer.MoveColumnVetoException {
+    public void testAppend() throws VetoException {
         final MetadataCol52 column = new MetadataCol52();
         column.setMetadata("smurf");
 
@@ -45,14 +50,14 @@ public class MetaDataColumnSynchronizerTest extends BaseSynchronizerTest {
         assertEquals("smurf",
                      model.getMetadataCols().get(0).getMetadata());
 
-        assertEquals(3,
+        assertEquals(4,
                      uiModel.getColumns().size());
         assertEquals("smurf",
-                     uiModel.getColumns().get(2).getHeaderMetaData().get(0).getTitle());
+                     uiModel.getColumns().get(3).getHeaderMetaData().get(0).getTitle());
     }
 
     @Test
-    public void testUpdate1() throws ModelSynchronizer.MoveColumnVetoException {
+    public void testUpdate1() throws VetoException {
         final MetadataCol52 column = spy(new MetadataCol52());
         column.setMetadata("smurf");
 
@@ -73,14 +78,14 @@ public class MetaDataColumnSynchronizerTest extends BaseSynchronizerTest {
         assertEquals("changed",
                      model.getMetadataCols().get(0).getMetadata());
 
-        assertEquals(3,
+        assertEquals(4,
                      uiModel.getColumns().size());
         assertEquals("changed",
-                     uiModel.getColumns().get(2).getHeaderMetaData().get(0).getTitle());
+                     uiModel.getColumns().get(3).getHeaderMetaData().get(0).getTitle());
     }
 
     @Test
-    public void testUpdate2() throws ModelSynchronizer.MoveColumnVetoException {
+    public void testUpdate2() throws VetoException {
         final MetadataCol52 column = spy(new MetadataCol52());
         column.setMetadata("smurf");
 
@@ -102,16 +107,16 @@ public class MetaDataColumnSynchronizerTest extends BaseSynchronizerTest {
         assertEquals("smurf",
                      model.getMetadataCols().get(0).getMetadata());
 
-        assertEquals(3,
+        assertEquals(4,
                      uiModel.getColumns().size());
         assertEquals("smurf",
-                     uiModel.getColumns().get(2).getHeaderMetaData().get(0).getTitle());
+                     uiModel.getColumns().get(3).getHeaderMetaData().get(0).getTitle());
         assertEquals(false,
-                     uiModel.getColumns().get(2).isVisible());
+                     uiModel.getColumns().get(3).isVisible());
     }
 
     @Test
-    public void testDelete() throws ModelSynchronizer.MoveColumnVetoException {
+    public void testDelete() throws VetoException {
         final MetadataCol52 column = new MetadataCol52();
         column.setMetadata("smurf");
 
@@ -119,18 +124,18 @@ public class MetaDataColumnSynchronizerTest extends BaseSynchronizerTest {
 
         assertEquals(1,
                      model.getMetadataCols().size());
-        assertEquals(3,
+        assertEquals(4,
                      uiModel.getColumns().size());
 
         modelSynchronizer.deleteColumn(column);
         assertEquals(0,
                      model.getMetadataCols().size());
-        assertEquals(2,
+        assertEquals(3,
                      uiModel.getColumns().size());
     }
 
     @Test
-    public void testMoveColumnTo_MoveLeft() throws ModelSynchronizer.MoveColumnVetoException {
+    public void testMoveColumnTo_MoveLeft() throws VetoException {
         final MetadataCol52 column1 = new MetadataCol52();
         column1.setMetadata("metadata1");
         final MetadataCol52 column2 = new MetadataCol52();
@@ -140,12 +145,12 @@ public class MetaDataColumnSynchronizerTest extends BaseSynchronizerTest {
         modelSynchronizer.appendColumn(column2);
 
         modelSynchronizer.appendRow();
-        uiModel.setCell(0,
-                        2,
-                        new BaseGridCellValue<String>("metadata1"));
-        uiModel.setCell(0,
-                        3,
-                        new BaseGridCellValue<String>("metadata2"));
+        uiModel.setCellValue(0,
+                             3,
+                             new BaseGridCellValue<String>("metadata1"));
+        uiModel.setCellValue(0,
+                             4,
+                             new BaseGridCellValue<String>("metadata2"));
 
         assertEquals(2,
                      model.getMetadataCols().size());
@@ -154,30 +159,30 @@ public class MetaDataColumnSynchronizerTest extends BaseSynchronizerTest {
         assertEquals(column2,
                      model.getMetadataCols().get(1));
         assertEquals("metadata1",
-                     model.getData().get(0).get(2).getStringValue());
-        assertEquals("metadata2",
                      model.getData().get(0).get(3).getStringValue());
+        assertEquals("metadata2",
+                     model.getData().get(0).get(4).getStringValue());
 
-        assertEquals(4,
+        assertEquals(5,
                      uiModel.getColumns().size());
-        final GridColumn<?> uiModelColumn1_1 = uiModel.getColumns().get(2);
-        final GridColumn<?> uiModelColumn2_1 = uiModel.getColumns().get(3);
+        final GridColumn<?> uiModelColumn1_1 = uiModel.getColumns().get(3);
+        final GridColumn<?> uiModelColumn2_1 = uiModel.getColumns().get(4);
         assertEquals("metadata1",
                      uiModelColumn1_1.getHeaderMetaData().get(0).getTitle());
         assertEquals("metadata2",
                      uiModelColumn2_1.getHeaderMetaData().get(0).getTitle());
         assertTrue(uiModelColumn1_1 instanceof StringUiColumn);
         assertTrue(uiModelColumn2_1 instanceof StringUiColumn);
-        assertEquals(2,
-                     uiModelColumn1_1.getIndex());
         assertEquals(3,
+                     uiModelColumn1_1.getIndex());
+        assertEquals(4,
                      uiModelColumn2_1.getIndex());
         assertEquals("metadata1",
                      uiModel.getRow(0).getCells().get(uiModelColumn1_1.getIndex()).getValue().getValue());
         assertEquals("metadata2",
                      uiModel.getRow(0).getCells().get(uiModelColumn2_1.getIndex()).getValue().getValue());
 
-        uiModel.moveColumnTo(2,
+        uiModel.moveColumnTo(3,
                              uiModelColumn2_1);
 
         assertEquals(2,
@@ -187,23 +192,23 @@ public class MetaDataColumnSynchronizerTest extends BaseSynchronizerTest {
         assertEquals(column1,
                      model.getMetadataCols().get(1));
         assertEquals("metadata2",
-                     model.getData().get(0).get(2).getStringValue());
-        assertEquals("metadata1",
                      model.getData().get(0).get(3).getStringValue());
+        assertEquals("metadata1",
+                     model.getData().get(0).get(4).getStringValue());
 
-        assertEquals(4,
+        assertEquals(5,
                      uiModel.getColumns().size());
-        final GridColumn<?> uiModelColumn1_2 = uiModel.getColumns().get(2);
-        final GridColumn<?> uiModelColumn2_2 = uiModel.getColumns().get(3);
+        final GridColumn<?> uiModelColumn1_2 = uiModel.getColumns().get(3);
+        final GridColumn<?> uiModelColumn2_2 = uiModel.getColumns().get(4);
         assertEquals("metadata2",
                      uiModelColumn1_2.getHeaderMetaData().get(0).getTitle());
         assertEquals("metadata1",
                      uiModelColumn2_2.getHeaderMetaData().get(0).getTitle());
         assertTrue(uiModelColumn1_2 instanceof StringUiColumn);
         assertTrue(uiModelColumn2_2 instanceof StringUiColumn);
-        assertEquals(3,
+        assertEquals(4,
                      uiModelColumn1_2.getIndex());
-        assertEquals(2,
+        assertEquals(3,
                      uiModelColumn2_2.getIndex());
         assertEquals("metadata2",
                      uiModel.getRow(0).getCells().get(uiModelColumn1_2.getIndex()).getValue().getValue());
@@ -212,7 +217,7 @@ public class MetaDataColumnSynchronizerTest extends BaseSynchronizerTest {
     }
 
     @Test
-    public void testMoveColumnTo_MoveRight() throws ModelSynchronizer.MoveColumnVetoException {
+    public void testMoveColumnTo_MoveRight() throws VetoException {
         final MetadataCol52 column1 = new MetadataCol52();
         column1.setMetadata("metadata1");
         final MetadataCol52 column2 = new MetadataCol52();
@@ -222,12 +227,12 @@ public class MetaDataColumnSynchronizerTest extends BaseSynchronizerTest {
         modelSynchronizer.appendColumn(column2);
 
         modelSynchronizer.appendRow();
-        uiModel.setCell(0,
-                        2,
-                        new BaseGridCellValue<String>("metadata1"));
-        uiModel.setCell(0,
-                        3,
-                        new BaseGridCellValue<String>("metadata2"));
+        uiModel.setCellValue(0,
+                             3,
+                             new BaseGridCellValue<String>("metadata1"));
+        uiModel.setCellValue(0,
+                             4,
+                             new BaseGridCellValue<String>("metadata2"));
 
         assertEquals(2,
                      model.getMetadataCols().size());
@@ -236,30 +241,30 @@ public class MetaDataColumnSynchronizerTest extends BaseSynchronizerTest {
         assertEquals(column2,
                      model.getMetadataCols().get(1));
         assertEquals("metadata1",
-                     model.getData().get(0).get(2).getStringValue());
-        assertEquals("metadata2",
                      model.getData().get(0).get(3).getStringValue());
+        assertEquals("metadata2",
+                     model.getData().get(0).get(4).getStringValue());
 
-        assertEquals(4,
+        assertEquals(5,
                      uiModel.getColumns().size());
-        final GridColumn<?> uiModelColumn1_1 = uiModel.getColumns().get(2);
-        final GridColumn<?> uiModelColumn2_1 = uiModel.getColumns().get(3);
+        final GridColumn<?> uiModelColumn1_1 = uiModel.getColumns().get(3);
+        final GridColumn<?> uiModelColumn2_1 = uiModel.getColumns().get(4);
         assertEquals("metadata1",
                      uiModelColumn1_1.getHeaderMetaData().get(0).getTitle());
         assertEquals("metadata2",
                      uiModelColumn2_1.getHeaderMetaData().get(0).getTitle());
         assertTrue(uiModelColumn1_1 instanceof StringUiColumn);
         assertTrue(uiModelColumn2_1 instanceof StringUiColumn);
-        assertEquals(2,
-                     uiModelColumn1_1.getIndex());
         assertEquals(3,
+                     uiModelColumn1_1.getIndex());
+        assertEquals(4,
                      uiModelColumn2_1.getIndex());
         assertEquals("metadata1",
                      uiModel.getRow(0).getCells().get(uiModelColumn1_1.getIndex()).getValue().getValue());
         assertEquals("metadata2",
                      uiModel.getRow(0).getCells().get(uiModelColumn2_1.getIndex()).getValue().getValue());
 
-        uiModel.moveColumnTo(3,
+        uiModel.moveColumnTo(4,
                              uiModelColumn1_1);
 
         assertEquals(2,
@@ -269,23 +274,23 @@ public class MetaDataColumnSynchronizerTest extends BaseSynchronizerTest {
         assertEquals(column1,
                      model.getMetadataCols().get(1));
         assertEquals("metadata2",
-                     model.getData().get(0).get(2).getStringValue());
-        assertEquals("metadata1",
                      model.getData().get(0).get(3).getStringValue());
+        assertEquals("metadata1",
+                     model.getData().get(0).get(4).getStringValue());
 
-        assertEquals(4,
+        assertEquals(5,
                      uiModel.getColumns().size());
-        final GridColumn<?> uiModelColumn1_2 = uiModel.getColumns().get(2);
-        final GridColumn<?> uiModelColumn2_2 = uiModel.getColumns().get(3);
+        final GridColumn<?> uiModelColumn1_2 = uiModel.getColumns().get(3);
+        final GridColumn<?> uiModelColumn2_2 = uiModel.getColumns().get(4);
         assertEquals("metadata2",
                      uiModelColumn1_2.getHeaderMetaData().get(0).getTitle());
         assertEquals("metadata1",
                      uiModelColumn2_2.getHeaderMetaData().get(0).getTitle());
         assertTrue(uiModelColumn1_2 instanceof StringUiColumn);
         assertTrue(uiModelColumn2_2 instanceof StringUiColumn);
-        assertEquals(3,
+        assertEquals(4,
                      uiModelColumn1_2.getIndex());
-        assertEquals(2,
+        assertEquals(3,
                      uiModelColumn2_2.getIndex());
         assertEquals("metadata2",
                      uiModel.getRow(0).getCells().get(uiModelColumn1_2.getIndex()).getValue().getValue());
@@ -294,7 +299,7 @@ public class MetaDataColumnSynchronizerTest extends BaseSynchronizerTest {
     }
 
     @Test
-    public void testMoveColumnTo_OutOfBounds() throws ModelSynchronizer.MoveColumnVetoException {
+    public void testMoveColumnTo_OutOfBounds() throws VetoException {
         final MetadataCol52 column1 = new MetadataCol52();
         column1.setMetadata("metadata1");
         final MetadataCol52 column2 = new MetadataCol52();
@@ -304,12 +309,12 @@ public class MetaDataColumnSynchronizerTest extends BaseSynchronizerTest {
         modelSynchronizer.appendColumn(column2);
 
         modelSynchronizer.appendRow();
-        uiModel.setCell(0,
-                        2,
-                        new BaseGridCellValue<String>("metadata1"));
-        uiModel.setCell(0,
-                        3,
-                        new BaseGridCellValue<String>("metadata2"));
+        uiModel.setCellValue(0,
+                             3,
+                             new BaseGridCellValue<String>("metadata1"));
+        uiModel.setCellValue(0,
+                             4,
+                             new BaseGridCellValue<String>("metadata2"));
 
         assertEquals(2,
                      model.getMetadataCols().size());
@@ -318,30 +323,30 @@ public class MetaDataColumnSynchronizerTest extends BaseSynchronizerTest {
         assertEquals(column2,
                      model.getMetadataCols().get(1));
         assertEquals("metadata1",
-                     model.getData().get(0).get(2).getStringValue());
-        assertEquals("metadata2",
                      model.getData().get(0).get(3).getStringValue());
+        assertEquals("metadata2",
+                     model.getData().get(0).get(4).getStringValue());
 
-        assertEquals(4,
+        assertEquals(5,
                      uiModel.getColumns().size());
-        final GridColumn<?> uiModelColumn1_1 = uiModel.getColumns().get(2);
-        final GridColumn<?> uiModelColumn2_1 = uiModel.getColumns().get(3);
+        final GridColumn<?> uiModelColumn1_1 = uiModel.getColumns().get(3);
+        final GridColumn<?> uiModelColumn2_1 = uiModel.getColumns().get(4);
         assertEquals("metadata1",
                      uiModelColumn1_1.getHeaderMetaData().get(0).getTitle());
         assertEquals("metadata2",
                      uiModelColumn2_1.getHeaderMetaData().get(0).getTitle());
         assertTrue(uiModelColumn1_1 instanceof StringUiColumn);
         assertTrue(uiModelColumn2_1 instanceof StringUiColumn);
-        assertEquals(2,
-                     uiModelColumn1_1.getIndex());
         assertEquals(3,
+                     uiModelColumn1_1.getIndex());
+        assertEquals(4,
                      uiModelColumn2_1.getIndex());
         assertEquals("metadata1",
                      uiModel.getRow(0).getCells().get(uiModelColumn1_1.getIndex()).getValue().getValue());
         assertEquals("metadata2",
                      uiModel.getRow(0).getCells().get(uiModelColumn2_1.getIndex()).getValue().getValue());
 
-        uiModel.moveColumnTo(0,
+        uiModel.moveColumnTo(1,
                              uiModelColumn1_1);
 
         assertEquals(2,
@@ -351,23 +356,23 @@ public class MetaDataColumnSynchronizerTest extends BaseSynchronizerTest {
         assertEquals(column2,
                      model.getMetadataCols().get(1));
         assertEquals("metadata1",
-                     model.getData().get(0).get(2).getStringValue());
-        assertEquals("metadata2",
                      model.getData().get(0).get(3).getStringValue());
+        assertEquals("metadata2",
+                     model.getData().get(0).get(4).getStringValue());
 
-        assertEquals(4,
+        assertEquals(5,
                      uiModel.getColumns().size());
-        final GridColumn<?> uiModelColumn1_2 = uiModel.getColumns().get(2);
-        final GridColumn<?> uiModelColumn2_2 = uiModel.getColumns().get(3);
+        final GridColumn<?> uiModelColumn1_2 = uiModel.getColumns().get(3);
+        final GridColumn<?> uiModelColumn2_2 = uiModel.getColumns().get(4);
         assertEquals("metadata1",
                      uiModelColumn1_2.getHeaderMetaData().get(0).getTitle());
         assertEquals("metadata2",
                      uiModelColumn2_2.getHeaderMetaData().get(0).getTitle());
         assertTrue(uiModelColumn1_2 instanceof StringUiColumn);
         assertTrue(uiModelColumn2_2 instanceof StringUiColumn);
-        assertEquals(2,
-                     uiModelColumn1_2.getIndex());
         assertEquals(3,
+                     uiModelColumn1_2.getIndex());
+        assertEquals(4,
                      uiModelColumn2_2.getIndex());
         assertEquals("metadata1",
                      uiModel.getRow(0).getCells().get(uiModelColumn1_2.getIndex()).getValue().getValue());
@@ -376,7 +381,7 @@ public class MetaDataColumnSynchronizerTest extends BaseSynchronizerTest {
     }
 
     @Test
-    public void testMoveColumnsTo_MoveLeft() throws ModelSynchronizer.MoveColumnVetoException {
+    public void testMoveColumnsTo_MoveLeft() throws VetoException {
         final MetadataCol52 column1 = new MetadataCol52();
         column1.setMetadata("metadata1");
         final MetadataCol52 column2 = new MetadataCol52();
@@ -389,19 +394,19 @@ public class MetaDataColumnSynchronizerTest extends BaseSynchronizerTest {
         modelSynchronizer.appendColumn(column3);
 
         modelSynchronizer.appendRow();
-        uiModel.setCell(0,
-                        2,
-                        new BaseGridCellValue<String>("metadata1"));
-        uiModel.setCell(0,
-                        3,
-                        new BaseGridCellValue<String>("metadata2"));
-        uiModel.setCell(0,
-                        4,
-                        new BaseGridCellValue<String>("metadata3"));
+        uiModel.setCellValue(0,
+                             3,
+                             new BaseGridCellValue<String>("metadata1"));
+        uiModel.setCellValue(0,
+                             4,
+                             new BaseGridCellValue<String>("metadata2"));
+        uiModel.setCellValue(0,
+                             5,
+                             new BaseGridCellValue<String>("metadata3"));
 
-        final GridColumn<?> uiModelColumn1_1 = uiModel.getColumns().get(2);
-        final GridColumn<?> uiModelColumn2_1 = uiModel.getColumns().get(3);
-        final GridColumn<?> uiModelColumn3_1 = uiModel.getColumns().get(4);
+        final GridColumn<?> uiModelColumn1_1 = uiModel.getColumns().get(3);
+        final GridColumn<?> uiModelColumn2_1 = uiModel.getColumns().get(4);
+        final GridColumn<?> uiModelColumn3_1 = uiModel.getColumns().get(5);
 
         assertTestMoveColumnsTo(column1,
                                 column2,
@@ -411,15 +416,15 @@ public class MetaDataColumnSynchronizerTest extends BaseSynchronizerTest {
                                 uiModelColumn3_1);
 
         //Moving multiple MetaData columns as an unsupported operation as it's impossible via the UI
-        uiModel.moveColumnsTo(2,
+        uiModel.moveColumnsTo(3,
                               new ArrayList<GridColumn<?>>() {{
                                   add(uiModelColumn2_1);
                                   add(uiModelColumn3_1);
                               }});
 
-        final GridColumn<?> uiModelColumn1_2 = uiModel.getColumns().get(2);
-        final GridColumn<?> uiModelColumn2_2 = uiModel.getColumns().get(3);
-        final GridColumn<?> uiModelColumn3_2 = uiModel.getColumns().get(4);
+        final GridColumn<?> uiModelColumn1_2 = uiModel.getColumns().get(3);
+        final GridColumn<?> uiModelColumn2_2 = uiModel.getColumns().get(4);
+        final GridColumn<?> uiModelColumn3_2 = uiModel.getColumns().get(5);
 
         assertTestMoveColumnsTo(column1,
                                 column2,
@@ -430,7 +435,7 @@ public class MetaDataColumnSynchronizerTest extends BaseSynchronizerTest {
     }
 
     @Test
-    public void testMoveColumnsTo_MoveRight() throws ModelSynchronizer.MoveColumnVetoException {
+    public void testMoveColumnsTo_MoveRight() throws VetoException {
         final MetadataCol52 column1 = new MetadataCol52();
         column1.setMetadata("metadata1");
         final MetadataCol52 column2 = new MetadataCol52();
@@ -443,19 +448,19 @@ public class MetaDataColumnSynchronizerTest extends BaseSynchronizerTest {
         modelSynchronizer.appendColumn(column3);
 
         modelSynchronizer.appendRow();
-        uiModel.setCell(0,
-                        2,
-                        new BaseGridCellValue<String>("metadata1"));
-        uiModel.setCell(0,
-                        3,
-                        new BaseGridCellValue<String>("metadata2"));
-        uiModel.setCell(0,
-                        4,
-                        new BaseGridCellValue<String>("metadata3"));
+        uiModel.setCellValue(0,
+                             3,
+                             new BaseGridCellValue<String>("metadata1"));
+        uiModel.setCellValue(0,
+                             4,
+                             new BaseGridCellValue<String>("metadata2"));
+        uiModel.setCellValue(0,
+                             5,
+                             new BaseGridCellValue<String>("metadata3"));
 
-        final GridColumn<?> uiModelColumn1_1 = uiModel.getColumns().get(2);
-        final GridColumn<?> uiModelColumn2_1 = uiModel.getColumns().get(3);
-        final GridColumn<?> uiModelColumn3_1 = uiModel.getColumns().get(4);
+        final GridColumn<?> uiModelColumn1_1 = uiModel.getColumns().get(3);
+        final GridColumn<?> uiModelColumn2_1 = uiModel.getColumns().get(4);
+        final GridColumn<?> uiModelColumn3_1 = uiModel.getColumns().get(5);
 
         assertTestMoveColumnsTo(column1,
                                 column2,
@@ -465,15 +470,15 @@ public class MetaDataColumnSynchronizerTest extends BaseSynchronizerTest {
                                 uiModelColumn3_1);
 
         //Moving multiple MetaData columns as an unsupported operation as it's impossible via the UI
-        uiModel.moveColumnsTo(4,
+        uiModel.moveColumnsTo(5,
                               new ArrayList<GridColumn<?>>() {{
                                   add(uiModelColumn1_1);
                                   add(uiModelColumn2_1);
                               }});
 
-        final GridColumn<?> uiModelColumn1_2 = uiModel.getColumns().get(2);
-        final GridColumn<?> uiModelColumn2_2 = uiModel.getColumns().get(3);
-        final GridColumn<?> uiModelColumn3_2 = uiModel.getColumns().get(4);
+        final GridColumn<?> uiModelColumn1_2 = uiModel.getColumns().get(3);
+        final GridColumn<?> uiModelColumn2_2 = uiModel.getColumns().get(4);
+        final GridColumn<?> uiModelColumn3_2 = uiModel.getColumns().get(5);
 
         assertTestMoveColumnsTo(column1,
                                 column2,
@@ -484,14 +489,14 @@ public class MetaDataColumnSynchronizerTest extends BaseSynchronizerTest {
     }
 
     @Test
-    public void checkHandlesMoveColumnsToWithEmptyMetadata() throws ModelSynchronizer.MoveColumnVetoException {
+    public void checkHandlesMoveColumnsToWithEmptyMetadata() throws VetoException {
         final MetaDataColumnSynchronizer synchronizer = new MetaDataColumnSynchronizer();
 
         assertFalse(synchronizer.handlesMoveColumnsTo(Collections.emptyList()));
     }
 
     @Test
-    public void checkHandlesMoveColumnsToWithMultipleMetadata() throws ModelSynchronizer.MoveColumnVetoException {
+    public void checkHandlesMoveColumnsToWithMultipleMetadata() throws VetoException {
         final BaseSynchronizer.MoveColumnToMetaData md0 = mock(BaseSynchronizer.MoveColumnToMetaData.class);
         final BaseSynchronizer.MoveColumnToMetaData md1 = mock(BaseSynchronizer.MoveColumnToMetaData.class);
         final MetaDataColumnSynchronizer synchronizer = new MetaDataColumnSynchronizer();
@@ -505,7 +510,7 @@ public class MetaDataColumnSynchronizerTest extends BaseSynchronizerTest {
     }
 
     @Test
-    public void checkHandlesMoveColumnsToWithSingleMetadata() throws ModelSynchronizer.MoveColumnVetoException {
+    public void checkHandlesMoveColumnsToWithSingleMetadata() throws VetoException {
         final BaseSynchronizer.MoveColumnToMetaData md0 = mock(BaseSynchronizer.MoveColumnToMetaData.class);
         final MetaDataColumnSynchronizer synchronizer = new MetaDataColumnSynchronizer();
         when(md0.getColumn()).thenReturn(mock(MetadataCol52.class));
@@ -528,13 +533,13 @@ public class MetaDataColumnSynchronizerTest extends BaseSynchronizerTest {
         assertEquals(column3,
                      model.getMetadataCols().get(2));
         assertEquals("metadata1",
-                     model.getData().get(0).get(2).getStringValue());
-        assertEquals("metadata2",
                      model.getData().get(0).get(3).getStringValue());
-        assertEquals("metadata3",
+        assertEquals("metadata2",
                      model.getData().get(0).get(4).getStringValue());
+        assertEquals("metadata3",
+                     model.getData().get(0).get(5).getStringValue());
 
-        assertEquals(5,
+        assertEquals(6,
                      uiModel.getColumns().size());
         assertEquals("metadata1",
                      uiModelColumn1.getHeaderMetaData().get(0).getTitle());
@@ -545,11 +550,11 @@ public class MetaDataColumnSynchronizerTest extends BaseSynchronizerTest {
         assertTrue(uiModelColumn1 instanceof StringUiColumn);
         assertTrue(uiModelColumn2 instanceof StringUiColumn);
         assertTrue(uiModelColumn3 instanceof StringUiColumn);
-        assertEquals(2,
-                     uiModelColumn1.getIndex());
         assertEquals(3,
-                     uiModelColumn2.getIndex());
+                     uiModelColumn1.getIndex());
         assertEquals(4,
+                     uiModelColumn2.getIndex());
+        assertEquals(5,
                      uiModelColumn3.getIndex());
         assertEquals("metadata1",
                      uiModel.getRow(0).getCells().get(uiModelColumn1.getIndex()).getValue().getValue());
